[![Ubuntu unit tests](https://github.com/MichaelClerx/bnglonglat/workflows/Ubuntu%20unit%20tests/badge.svg)](https://github.com/MichaelClerx/bnglonglat/actions?query=workflow%3A"Ubuntu+unit+tests")
[![Style](https://github.com/MichaelClerx/bnglonglat/workflows/Style/badge.svg)](https://github.com/MichaelClerx/bnglonglat/actions?query=workflow%3A"Style")

# British National Grid to Longitude/Lattitude

Pure python implementation of `convert_lonlat` from [lonlat_bng](https://github.com/urschrei/lonlat_bng).

Note: This uses the version without OSTN15 corrections, which can be several meters off.

## License

This code is available under an MIT license, See [license.txt](./license.txt).

It is based on [lonlat_bng](https://github.com/urschrei/lonlat_bng), which is Copyright (c) 2015 Stephan Hügel, and also published with an MIT license.
